==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/peregrin.pl <==
#============================================================================================================
#
#	ǗOf[^ǗW[(PEREGRIN)
#	peregrin.pl
#	----------------------------------------
#	2003.01.07 start
#	2003.01.22 ʃC^tFCXֈڍs
#	2003.03.06 ÕG[FIX
#	2003.06.25 Add\bhǉ
#
#	낿˂vX
#	2010.08.13 ꕔOo͌`ύX
#	2010.08.14 ꕔOo͌`ύX
#
#============================================================================================================
package	PEREGRIN;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@F
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@LOG, $PATH, $FILE, $MAX, $MAXA, $MAXH, $KIND, $obj);
	
	$obj = {
		'LOG'	=> \@LOG,
		'PATH'	=> $PATH,
		'FILE'	=> $FILE,
		'MAX'	=> $MAX,
		'MAXA'	=> $MAXA,
		'MAXH'	=> $MAXH,
		'KIND'	=> $KIND,
		'NUM'	=> 0
	};
	
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	fXgN^ - DESTROY
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub DESTROY
{
}

#------------------------------------------------------------------------------------------------------------
#
#	Oǂݍ - Load
#	------------------------------------------------
#	@F$M   : MELKOR
#			$log : O
#			$key : XbhL[(݂̏ꍇ̂)
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($M, $log, $key) = @_;
	my ($path, $file, $kind);
	
	undef @{$this->{'LOG'}};
	$this->{'PATH'}	= '';
	$this->{'FILE'}	= '';
	$this->{'KIND'}	= 0;
	$this->{'MAX'}	= $M->Get('ERRMAX');
	$this->{'MAXA'}	= $M->Get('ADMMAX');
	$this->{'MAXH'}	= $M->Get('HISMAX');
	$this->{'NUM'}	= 0;
	
	$path = $M->Get('BBSPATH') . '/' . $M->Get('BBS') . '/log';		# fpX
	
	if ($log eq 'ERR')		{ $file = 'errs.cgi';	$kind = 1; }	# G[O
	elsif ($log eq 'THR')	{ $file = 'IP.cgi';		$kind = 2; }	# Xbh쐬O
	elsif ($log eq 'WRT')	{ $file = "$key.cgi";	$kind = 3; }	# ݃O
	elsif ($log eq 'HST')	{ $file = "HOSTs.cgi";	$kind = 5; }	# zXgO
	elsif ($log eq 'SMB')	{ $file = "samba.cgi";	$kind = 6; }	# SambaO
	elsif ($log eq 'SBH')	{ $file = "houshi.cgi";	$kind = 7; }	# SambaKO
	else {															# ُ
		$file = '';
		$kind = 0;
	}
	
	if ($kind) {													# ɐݒ
		if (-e "$path/$file") {
			open LOG, "< $path/$file";
			while (<LOG>) {
				push @{$this->{'LOG'}}, $_;
				$this->{'NUM'}++;
			}
			close LOG;
		}
		$this->{'PATH'} = $path;
		$this->{'FILE'} = $file;
	}
	$this->{'KIND'} = $kind;
}

#------------------------------------------------------------------------------------------------------------
#
#	G[O - SaveError
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($M) = @_;
	my ($path, $file);
	
	$path	= $this->{'PATH'};
	$file	= $this->{'FILE'};
	
	if ($this->{'KIND'}) {
#		eval
		{ chmod 0666, "$path/$file"; };				# p[~bVݒ
		if (open LOG, "> $path/$file") {
			flock LOG, 2;
			truncate LOG, 0;
			seek LOG, 0, 0;
			print LOG @{$this->{'LOG'}};
			close LOG;
		}
#		eval
		{ chmod $M->Get('PM-LOG'), "$path/$file"; };	# p[~bVݒ
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	Oǉ - Set
#	-------------------------------------------
#	@F$I     : ISILDUR
#			$data1 : ėpf[^1
#			$data2 : ėpf[^2
#			$host  : [gzXg
#			$data  : DAT`̃O
#			$mode  : ID
#	߂lFȂ
#
#	2010.08.12 windyakin 
#	 -> ʏ폑݃Oo͌`Q˂`֕ύX
#
#	2010.08.14 windyakin 
#	 -> g,p2HOST̃Oo͂ύX
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($I, $data1, $data2, $host, $data, $mode) = @_;
	my ($work, $nm, $tm, $bf, $kind, $tsw, @logdat);
	
	$bf		= 0;
	$nm		= $this->{'NUM'};														# O擾
	$kind	= $this->{'KIND'};
	$tsw	= $ENV{'REMOTE_HOST'};
	$mode	= '0' if (! defined $mode);
	
	if ($mode ne '0') {
		if ($mode eq 'P') {
			$host = "$tsw($host)$ENV{'REMOTE_ADDR'}";
		}
		else {
			$host = "$tsw($host)";
		}
	}
	
	if ($kind) {																	# ǂݍݍς
		$tm = time;
		
		if ($kind eq 3) {
			
			@logdat = split(/<>/, $data, 5);
			
			$work = join('<>',
				$logdat[0],
				$logdat[1],
				$logdat[2],
				substr($logdat[3], 0, 30),
				$logdat[4],
				$host,
				$ENV{'REMOTE_ADDR'},
				$data1,
				$ENV{'HTTP_USER_AGENT'}
			) . "\n";
			
		}
		else {
			$work = join('<>',
				$tm,
				$data1,
				$data2,
				$host
			) . "\n";
		}
		
		push @{$this->{'LOG'}}, $work;												# ֒ǉ
		$nm = ++$this->{'NUM'};
		
		   if ($kind == 1) { $bf = $nm - $this->{'MAX'}; }							# G[O
		elsif ($kind == 2) { $bf = $nm - $I->Get('BBS_THREAD_TATESUGI'); }			# XbhO
		elsif ($kind == 3) { $bf = $nm - $I->Get('timecount'); }					# ݃O
		
		foreach (1 .. $bf) {														# Oőlz
			shift @{$this->{'LOG'}};												# 擪O̍폜
			$this->{'NUM'}--;
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	O擾 - Get
#	-------------------------------------------
#	@F$ln : Oԍ
#	߂lF@data
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($ln) = @_;
	my (@data, $work);
	
	$work = $this->{'LOG'}->[$ln];
	chomp $work;
	@data = split(/<>/, $work);
	
	return @data;
}

#------------------------------------------------------------------------------------------------------------
#
#	O - Search
#	-------------------------------------------
#	@F$data : T[`L[
#			$f    : T[`[h
#	߂lF1,Ȃ0
#
#	2010.08.13 windyakin 
#	 -> Oۑ`ύXɂVXe̕ύX
#
#------------------------------------------------------------------------------------------------------------
sub Search
{
	my $this = shift;
	my ($data, $f) = @_;
	my ($key, $dmy, $num, $i, $dat, $kind);
	
	$kind = $this->{'KIND'};
	
	if ($f == 1) {												# data1Ō
		$num = @{$this->{'LOG'}};
		for ($i = $num - 1 ; $i >= 0 ; $i--) {
			$dmy = $this->{'LOG'}->[$i];
			chomp $dmy;
			($key, $dat) = (split /<>/, $dmy)[$kind == 3 ? (5, 7) : (1, 3)];
			if ($data eq $key) {
				return $dat;
			}
		}
	}
	elsif ($f == 2) {											# hosto
		$num = 0;
		$dat = @{$this->{'LOG'}};
		for ($i = $dat - 1;$i >= 0;$i--) {
			$dmy = $this->{'LOG'}->[$i];
			chomp $dmy;
			$key = (split /<>/, $dmy)[$kind == 3 ? 5 : 3];
			if ($data eq $key) {
				$num++;
			}
		}
		return $num;
	}
	if ($f == 3) {												# THR
		$num = 0;
		$dat = @{$this->{'LOG'}};
		for ($i = $dat - 1 ; $i >= 0 ; $i--) {
			$dmy = $this->{'LOG'}->[$i];
			chomp $dmy;
			($key, $dat) = (split /<>/, $dmy)[1, 3];
			if ($data eq $dat) {
				$num++;
			}
		}
		return $num;
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Ԕ - IsTime
#	-------------------------------------------
#	@F$tmn : 莞(b)
#	߂lFԓ:cb,ԊO:0
#	@lFŏIO$tmnbo߂ǂ𔻒
#
#------------------------------------------------------------------------------------------------------------
sub IsTime
{
	my $this = shift;
	my ($tmn, $host) = @_;
	my ($i, $n, $work, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return 0 if ($kind == 3);
	
	for ($i = $n - 1 ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		return (($_ = $tmn - ($nw - $tm)) > 0 ? $_ : 0);	# cbԂ
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Samba - IsSamba
#	-------------------------------------------
#	@F$sb			: Samba(b)
#			$host		: 
#	߂lF$n			: Samba
#			$tm			: Kv҂
#
#------------------------------------------------------------------------------------------------------------
sub IsSamba
{
	my $this = shift;
	my ($sb, $host) = @_;
	my (@iplist, $i, $j, $n, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return (0, 0) if ($kind != 6);
	
	for ($i = $n - 1, $j = $nw ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		if ($sb > $j - $tm) {
			push @iplist, $tm;
			$j = $tm;
		}
		else {
			last;
		}
	}
	$n = @iplist;
	if ($n) {
		return ($n, ($nw - $iplist[0]));
	}
	return (0, 0);
}

#------------------------------------------------------------------------------------------------------------
#
#	d - IsHoushi
#	-------------------------------------------
#	@F$houshi		: d()
#			$host		: 
#	߂lF$ishoushi	: d
#			$tm			: Kv҂()
#
#------------------------------------------------------------------------------------------------------------
sub IsHoushi
{
	my $this = shift;
	my ($houshi, $host) = @_;
	my (@iplist, $i, $n, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return (0, 0) if ($kind != 7);
	
	for ($i = $n - 1 ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		if ($houshi * 60 > ($_ = $nw - $tm)) {
			return (1, $houshi - ($_ - ($_ % 60 || 60)) / 60);
		}
		else {
			return (0, 0);
		}
	}
	return (0, 0);
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/module/peregrin.pl <==
#============================================================================================================
#
#	ǗOf[^ǗW[(PEREGRIN)
#	peregrin.pl
#	----------------------------------------
#	2003.01.07 start
#	2003.01.22 ʃC^tFCXֈڍs
#	2003.03.06 ÕG[FIX
#	2003.06.25 Add\bhǉ
#
#	낿˂vX
#	2010.08.13 ꕔOo͌`ύX
#	2010.08.14 ꕔOo͌`ύX
#
#============================================================================================================
package	PEREGRIN;

use strict;
#RgAEgOꍇ͕ϐ̏`FbN邱ƁB
#use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@F
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@LOG, $PATH, $FILE, $MAX, $MAXA, $MAXH, $KIND, $obj);
	
	$obj = {
		'LOG'	=> \@LOG,
		'PATH'	=> $PATH,
		'FILE'	=> $FILE,
		'MAX'	=> $MAX,
		'MAXA'	=> $MAXA,
		'MAXH'	=> $MAXH,
		'KIND'	=> $KIND,
		'NUM'	=> 0
	};
	
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	fXgN^ - DESTROY
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub DESTROY
{
}

#------------------------------------------------------------------------------------------------------------
#
#	Oǂݍ - Load
#	------------------------------------------------
#	@F$M   : MELKOR
#			$log : O
#			$key : XbhL[(݂̏ꍇ̂)
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Load
{
	my $this = shift;
	my ($M, $log, $key) = @_;
	my ($path, $file, $kind);
	
	undef @{$this->{'LOG'}};
	$this->{'PATH'}	= '';
	$this->{'FILE'}	= '';
	$this->{'KIND'}	= 0;
	$this->{'MAX'}	= $M->Get('ERRMAX');
	$this->{'MAXA'}	= $M->Get('ADMMAX');
	$this->{'MAXH'}	= $M->Get('HISMAX');
	$this->{'NUM'}	= 0;
	
	$path = $M->Get('BBSPATH') . '/' . $M->Get('BBS') . '/log';		# fpX
	
	if ($log eq 'ERR')		{ $file = 'errs.cgi';	$kind = 1; }	# G[O
	elsif ($log eq 'THR')	{ $file = 'IP.cgi';		$kind = 2; }	# Xbh쐬O
	elsif ($log eq 'WRT')	{ $file = "$key.cgi";	$kind = 3; }	# ݃O
	elsif ($log eq 'HST')	{ $file = "HOST.cgi";	$kind = 5; }	# zXgO
	elsif ($log eq 'SMB')	{ $file = "samba.cgi";	$kind = 6; }	# SambaO
	elsif ($log eq 'SBH')	{ $file = "houshi.cgi";	$kind = 7; }	# SambaKO
	else {															# ُ
		$file = '';
		$kind = 0;
	}
	
	if ($kind) {													# ɐݒ
		if (-e "$path/$file") {
			open LOG, "< $path/$file";
			while (<LOG>) {
				push @{$this->{'LOG'}}, $_;
				$this->{'NUM'}++;
			}
			close LOG;
		}
		$this->{'PATH'} = $path;
		$this->{'FILE'} = $file;
	}
	$this->{'KIND'} = $kind;
}

#------------------------------------------------------------------------------------------------------------
#
#	G[O - SaveError
#	-------------------------------------------
#	@F$M : MELKOR
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Save
{
	my $this = shift;
	my ($M) = @_;
	my ($path, $file);
	
	$path	= $this->{'PATH'};
	$file	= $this->{'FILE'};
	
	if ($this->{'KIND'}) {
#		eval
		{ chmod 0666, "$path/$file"; };				# p[~bVݒ
		if (open LOG, "> $path/$file") {
			flock LOG, 2;
			truncate LOG, 0;
			seek LOG, 0, 0;
			print LOG @{$this->{'LOG'}};
			close LOG;
		}
#		eval
		{ chmod $M->Get('PM-LOG'), "$path/$file"; };	# p[~bVݒ
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	Oǉ - Set
#	-------------------------------------------
#	@F$I     : ISILDUR
#			$data1 : ėpf[^1
#			$data2 : ėpf[^2
#			$host  : [gzXg
#			$data  : DAT`̃O
#			$mode  : ID
#	߂lFȂ
#
#	2010.08.12 windyakin 
#	 -> ʏ폑݃Oo͌`Q˂`֕ύX
#
#	2010.08.14 windyakin 
#	 -> g,p2HOST̃Oo͂ύX
#
#------------------------------------------------------------------------------------------------------------
sub Set
{
	my $this = shift;
	my ($I, $data1, $data2, $koyuu, $data, $mode) = @_;
	my ($work, $nm, $tm, $bf, $kind, $host, @logdat);
	
	$bf		= 0;
	$nm		= $this->{'NUM'};														# O擾
	$kind	= $this->{'KIND'};
	$host	= $ENV{'REMOTE_HOST'};
	$mode	= '0' if (! defined $mode);
	
	if ($mode ne '0') {
		if ($mode eq 'P') {
			$host = "$host($koyuu)$ENV{'REMOTE_ADDR'}";
		}
		else {
			$host = "$host($koyuu)";
		}
	}
	
	if ($kind) {																# ǂݍݍς
		$tm = time;
		
		if ($kind == 3) {
			
			@logdat = split(/<>/, $data, 5);
			
			$work = join('<>',
				$logdat[0],
				$logdat[1],
				$logdat[2],
				substr($logdat[3], 0, 30),
				$logdat[4],
				$host,
				$ENV{'REMOTE_ADDR'},
				$data1,
				$ENV{'HTTP_USER_AGENT'}
			) . "\n";
			
		}
		else {
			$work = join('<>',
				$tm,
				$data1,
				$data2,
				$host
			) . "\n";
		}
		
		push @{$this->{'LOG'}}, $work;												# ֒ǉ
		$nm = ++$this->{'NUM'};
		
		   if ($kind == 1) { $bf = $nm - $this->{'MAX'}; }							# G[O
		elsif ($kind == 2) { $bf = $nm - $I->Get('BBS_THREAD_TATESUGI'); }			# XbhO
	#	elsif ($kind == 3) { $bf = $nm - $I->Get('timecount'); }					# ݃O
		elsif ($kind == 6) { $bf = $nm - $this->{'MAX'}; }							# samba
		elsif ($kind == 7) { $bf = $nm - $this->{'MAX'}; }							# houshi
		
		foreach (1 .. $bf) {														# Oőlz
			shift @{$this->{'LOG'}};												# 擪O̍폜
			$this->{'NUM'}--;
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	O擾 - Get
#	-------------------------------------------
#	@F$ln : Oԍ
#	߂lF@data
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($ln) = @_;
	my (@data, $work);
	
	if ($ln >= 0 && $ln < $this->{'NUM'}) {
		$work = $this->{'LOG'}->[$ln];
		chomp $work;
		@data = split(/<>/, $work);
		
		return @data;
	}
	else {
		return undef;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	O擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	X
#
#------------------------------------------------------------------------------------------------------------
sub Size
{
	my $this = shift;
	
	return $this->{'NUM'};
}

#------------------------------------------------------------------------------------------------------------
#
#	O - Search
#	-------------------------------------------
#	@F$data : T[`L[
#			$f    : T[`[h
#	߂lF1,Ȃ0
#
#	2010.08.13 windyakin 
#	 -> Oۑ`ύXɂVXe̕ύX
#
#------------------------------------------------------------------------------------------------------------
sub Search
{
	my $this = shift;
	my ($data, $f, $mode, $host, $count) = @_;
	my ($key, $dmy, $num, $i, $dat, $kind, $data2);
	
	$kind = $this->{'KIND'};
	
	if ($f == 1) {												# data1Ō
		$num = @{$this->{'LOG'}};
		for ($i = $num - 1 ; $i >= 0 ; $i--) {
			$dmy = $this->{'LOG'}->[$i];
			chomp $dmy;
			($key, $dat) = (split /<>/, $dmy)[$kind == 3 ? (5, 7) : (1, 3)];
			$key =~ s/^.*?(\(.*\)).*?$/$1/;
			if ($data eq $key) {
				return $dat;
			}
		}
	}
	else {
		if ($mode ne '0') {
			if ($mode eq 'P') {
				$host = "$host($data)$ENV{'REMOTE_ADDR'}";
			}
			else {
				$host = "$host($data)";
			}
		}
		
		if ($f == 2) {											# hosto
			$num = 0;
			$dat = @{$this->{'LOG'}};
			$count = $dat if (! defined $count);
			for ($i = $dat - 1 ; $i >= $dat - $count ; $i--) {
				$dmy = $this->{'LOG'}->[$i];
				chomp $dmy;
				$key = (split /<>/, $dmy)[$kind == 3 ? 5 : $kind == 5 ? 1 : 3];
				$key =~ s/^.*?\((.*)\).*?$/$1/;
				if ($data eq $key) {
					$num++;
				}
			}
			return $num;
		}
		elsif ($f == 3) {											# THR
			$num = 0;
			$dat = @{$this->{'LOG'}};
			$count = $dat if (! defined $count);
			for ($i = $dat - 1 ; $i >= $dat - $count ; $i--) {
				$dmy = $this->{'LOG'}->[$i];
				chomp $dmy;
				($key, $data2) = (split /<>/, $dmy)[1, 3];
				$key =~ s/^.*?(\(.*\)).*?$/$1/;
				if ($data eq $data2) {
					$num++;
				}
			}
			return $num;
		}
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Ԕ - IsTime
#	-------------------------------------------
#	@F$tmn : 莞(b)
#	߂lFԓ:cb,ԊO:0
#	@lFŏIO$tmnbo߂ǂ𔻒
#
#------------------------------------------------------------------------------------------------------------
sub IsTime
{
	my $this = shift;
	my ($tmn, $host) = @_;
	my ($i, $n, $work, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return 0 if ($kind == 3);
	
	for ($i = $n - 1 ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		return (($_ = $tmn - ($nw - $tm)) > 0 ? $_ : 0);	# cbԂ
	}
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Samba - IsSamba
#	-------------------------------------------
#	@F$sb			: Samba(b)
#			$host		: 
#	߂lF$n			: Samba
#			$tm			: Kv҂
#
#------------------------------------------------------------------------------------------------------------
sub IsSamba
{
	my $this = shift;
	my ($sb, $host) = @_;
	my (@iplist, $i, $j, $n, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return (0, 0) if ($kind != 6);
	
	for ($i = $n - 1, $j = $nw ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		if ($sb > $j - $tm) {
			push @iplist, $tm;
			$j = $tm;
		}
		else {
			last;
		}
	}
	$n = @iplist;
	if ($n) {
		return ($n, ($nw - $iplist[0]));
	}
	return (0, 0);
}

#------------------------------------------------------------------------------------------------------------
#
#	d - IsHoushi
#	-------------------------------------------
#	@F$houshi		: d()
#			$host		: 
#	߂lF$ishoushi	: d
#			$tm			: Kv҂()
#
#------------------------------------------------------------------------------------------------------------
sub IsHoushi
{
	my $this = shift;
	my ($houshi, $host) = @_;
	my (@iplist, $i, $n, $tm, $nw, $hst, $kind);
	
	$nw = time;
	$n = @{$this->{'LOG'}};
	$kind = $this->{'KIND'};
	
	return (0, 0) if ($kind != 7);
	
	for ($i = $n - 1 ; $i >= 0 ; $i--) {
		($tm, undef, undef, $hst) = split(/<>/, $this->{'LOG'}->[$i]);
		chomp $hst;
		next if ($host ne $hst);
		if ($houshi * 60 > ($_ = $nw - $tm)) {
			return (1, $houshi - ($_ - ($_ % 60 || 60)) / 60);
		}
		else {
			return (0, 0);
		}
	}
	return (0, 0);
}

#------------------------------------------------------------------------------------------------------------
#
#	O1s폜 - Delete
#	-------------------------------------------
#	@F$num
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Delete
{
	my $this = shift;
	my ($num) = @_;
	my (@arr);
	
	splice @{$this->{'LOG'}}, $num, 1;
	$this->{'NUM'}--;
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
